<?php return array(
    'root' => array(
        'name' => 'nextcloud/contacts',
        'pretty_version' => 'v8.5.1',
        'version' => '8.5.1.0',
        'reference' => 'a5039c37718d5059786a75194801f7ee3107cffb',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'nextcloud/contacts' => array(
            'pretty_version' => 'v8.5.1',
            'version' => '8.5.1.0',
            'reference' => 'a5039c37718d5059786a75194801f7ee3107cffb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
